import { Plugin } from 'rollup';
export declare type EnvVarReplacements = Record<string, string | number | true>;
export declare type DevPlugin = {
    build: Function;
};
export declare type DevScript = {
    id: string;
    match: string[];
    type: string;
    cmd: string;
    watch?: string;
    plugin?: {
        build: (filepath: string) => {
            result: string;
        } | Promise<{
            result: string;
        }>;
    };
    args?: any;
};
export interface SnowpackConfig {
    extends?: string;
    exclude: string[];
    knownEntrypoints: string[];
    webDependencies?: {
        [packageName: string]: string;
    };
    scripts: DevScript[];
    homepage?: string;
    devOptions: {
        port: number;
        out: string;
        fallback: string;
        bundle: boolean | undefined;
    };
    installOptions: {
        dest: string;
        env: EnvVarReplacements;
        installTypes: boolean;
        sourceMap?: boolean | 'inline';
        externalPackage: string[];
        alias: {
            [key: string]: string;
        };
        rollup: {
            plugins: Plugin[];
            dedupe?: string[];
            namedExports?: {
                [filepath: string]: string[];
            };
        };
    };
}
export interface CLIFlags extends Omit<Partial<SnowpackConfig['installOptions']>, 'env'> {
    help?: boolean;
    version?: boolean;
    reload?: boolean;
    config?: string;
    env?: string[];
}
export declare function loadAndValidateConfig(flags: CLIFlags, pkgManifest: any): SnowpackConfig;
